@@ -13,7 +13,7 @@ except ImportError:
     _HAS_TF_KERAS = False
     pass
 
-__version__ = "0.9.2"
+__version__ = "0.9.3"
 
 _MAX_META_SIZE = 1024
 _META_SIGNATURE = "@@FSEQ@@"
@@ -283,9 +283,11 @@ class HyperSequenceFile(HyperSequence):
 
         if _PLATFORM == "Linux":
             mmap_kwargs["prot"] = mmap.PROT_READ
+        elif _PLATFORM == "Windows":
+            mmap_kwargs["access"] = mmap.ACCESS_READ
 
         self._mmap = mmap.mmap(self._fp.fileno(), self._records * self._dtype.itemsize,
-                               access=mmap.ACCESS_READ, offset=0, **mmap_kwargs)
+                               offset=0, **mmap_kwargs)
 
     def _load_meta(self):
         # Meta-data is located at the end of the file. To be sure we'll read the last _MAX_META_SIZE bytes
